@@ -1,4 +1,5 @@
-from src.di_container_ibragimoff.container import Container
+from typing import Any, Callable
+from di_container_ibragimoff.container import Container
 
 
 class TestService:
@@ -45,3 +46,24 @@ def test_factory():
     service = container.get('my_test_service')
     assert service.get_value() == 'Example text'
     assert service.get_number() == 5
+
+
+def set_number(c: Container, service: TestService) -> Any:
+    service.set_number(c.get('number'))
+    return service
+
+
+def test_tagged_definitions():
+    container = Container()
+
+    container.set('test', lambda c: 'Example text')
+    container.set('number', lambda c: 12)
+    container.set('test_tagged_service', lambda c: TestService(c))
+
+    container.set_tag('test_tagged_service', 'set_number_service')
+
+    for id in container.find_ids_by_tag('set_number_service'):
+        container.extends(id, set_number)
+
+    assert container.get('number') == 12
+    assert container.get('test_tagged_service').get_number() == 12
